@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ JobTrackerFilterProxyModel::JobTrackerFilterProxyModel(QObject *parent)
     setDynamicSortFilter(true);
 }
 
-JobTrackerFilterProxyModel::~JobTrackerFilterProxyModel()
-{
-}
+JobTrackerFilterProxyModel::~JobTrackerFilterProxyModel() = default;
 
 bool JobTrackerFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
